Transform Function Decorators
=============================================

Transform function decorators, provided by the ``pyterrier_alpha.transform`` module, allow you to
write more concise and expressive code when defining Transformers by removing boilerplate.

Right now, the only supported decorator is the :func:`~pyterrier_alpha.transform.by_query` decorator.

API Documentation
---------------------------------------------------------

.. autofunction:: pyterrier_alpha.transform.by_query
